@@ -22,7 +22,8 @@ def getRecentExps(mjd):
     exp = opsdb.Exposure
     cfg = opsdb.Configuration
 
-    exps = cf.select(exp.pk, cf.sn2, cf.camera_pk, exp.start_time, cfg.design_id)\
+    exps = cf.select(exp.pk, cf.sn2, cf.camera_pk, exp.start_time,
+                     exp.exposure_no, cfg.design_id)\
                 .join(exp)\
                 .join(cfg)\
                 .where(exp.start_time > useTime,
@@ -39,6 +40,7 @@ def getRecentExps(mjd):
         #             "b1": "--",
         #             "AP": "--"}
         exp_dicts[e["pk"]]["design"] = int(e["design"])
+        exp_dicts[e["pk"]]["exposure_no"] = int(e["exposure_no"])
         exp_dicts[e["pk"]]["timeStamp"] = e["start_time"].strftime("%H:%M:%S")
         # for f in e.CameraFrames:
         if e["camera"] == r1_db.pk and e["sn2"] is not None:
@@ -239,12 +241,12 @@ def getConfigurations(design_id=None):
                     "b1": 0,
                     "AP": 0}
         conf_id = int(e.configuration.configuration_id)
-        exp_dict["timeStamp"] = e.start_time.strftime("%H:%M:%S")
+        exp_dict["timeStamp"] = e.start_time.strftime("%Y-%m-%d")
         # exp_mjd = int(Time(e.start_time).mjd)  # this truncates so it's probably "wrong", TBD
         for f in e.CameraFrames:
-            if f.camera.pk == r1_db.pk and f.sn2 is not None and f.sn2 > 0.5:
+            if f.camera.pk == r1_db.pk and f.sn2 is not None and f.sn2 > 0.2:
                 exp_dict["r1"] = f.sn2
-            if f.camera.pk == b1_db.pk and f.sn2 is not None and f.sn2 > 0.5:
+            if f.camera.pk == b1_db.pk and f.sn2 is not None and f.sn2 > 0.2:
                 exp_dict["b1"] = f.sn2
             if f.camera.pk == ap_db.pk and f.ql_sn2 is not None and f.ql_sn2 > 100:
                 exp_dict["AP"] = f.ql_sn2
